Description how to build units witht the D-SI format is [here](StructureSIUnits.md).

## SI base units of measurement (platinum units) 
|D-SI Identifier|D-SI Medal|SI name|SI symbol |SI Reference| 
|-:|-:|-:|-:|-:| 
|\metre|platinum|metre|m|[1, Table 2]| 
|\kilogram<sup>(a</sup>|platinum|kilogram|kg|[1, Table 2]| 
|\second|platinum|second|s|[1, Table 2]| 
|\ampere|platinum|ampere|A|[1, Table 2]| 
|\kelvin|platinum|kelvin|K|[1, Table 2]| 
|\mole|platinum|mole|mol|[1, Table 2]| 
|\candela|platinum|candela|cd|[1, Table 2]|"

<sub>(a: It is not allowed to use unit kilogram with a prefix. </sub>

## D-SI additional platinum units of measurement 
|D-SI Identifier|D-SI Medal|SI name|SI symbol |SI Reference| 
|-:|-:|-:|-:|-:| 
|\one<sup>(b</sup>|platinum|one|1|[1, Sec. 2.2.1]| 
|\day|platinum|day|d|[1, Table 8]| 
|\hour|platinum|hour|h|[1, Table 8]| 
|\minute|platinum|minute|min|[1, Table 8]| 
|\degree|platinum|degree|°|[1, Table 8]| 
|\arcminute|platinum|arcminute|‘|[1, Table 8]| 
|\arcsecond|platinum|arcsecond|“|[1, Table 8]|"

<sub>(b: Unit one must not be used with a prefix of an exponent. </sub>

## SI derived units of measurement 
|D-SI Identifier|D-SI Medal|SI name|SI symbol |SI base unit expression|D-SI base unit expression|SI Reference| 
|-:|-:|-:|-:|-:|-:|-:| 
|\gram<sup>(c</sup>|gold|gram(a|g|10-3 kg|\kilogram|[1, Sec. 3]| 
|\radian|gold|radian|rad|m/m|\metre\metre\tothe{-1}|[1, Table 4]| 
|\steradian|gold|steradian|sr|m2/m2|\metre\tothe{2}\metre\tothe{-2}|[1, Table 4]| 
|\hertz|gold|hertz|Hz|s-1|\second\tothe{-1}|[1, Table 4]| 
|\newton|gold|newton|N|m kg s-2|\metre\kilogram\second\tothe{-2}|[1, Table 4]| 
|\pascal|gold|pascal|Pa|m-1 kg s-2|\metre\tothe{-1}\kilogram\second\tothe{-2}|[1, Table 4]| 
|\joule|gold|joule|J|m2 kg s-2|\metre\tothe{2}\kilogram\second\tothe{-2}|[1, Table 4]| 
|\watt|gold|watt|W|m2 kg s-3|\metre\tothe{2}\kilogram\second\tothe{-3}|[1, Table 4]| 
|\coulomb|gold|coulomb|C|s A|\second\ampere|[1, Table 4]| 
|\volt|gold|volt|V|m2 kg s-3 A-1|\metre\tothe{2}\kilogram\second\tothe{-3}\ampere\tothe{-1}|[1, Table 4]| 
|\farad|gold|farad|F|m-2 kg-1 s4 A2|\metre\tothe{-2}\kilogram\tothe{-1}\second\tothe{4}\ampere\tothe{2}|[1, Table 4]| 
|\ohm|gold|ohm|Ω|m2 kg s-3 A-2|\metre\tothe{2}\kilogram\second\tothe{-3}\ampere\tothe{-2}|[1, Table 4]| 
|\siemens|gold|siemens|S|m-2 kg-1 s3 A2|\metre\tothe{-2}\kilogram\tothe{-1}\second\tothe{3}\ampere\tothe{2}|[1, Table 4]| 
|\weber|gold|weber|Wb|m2 kg s-2 A-1|\metre\tothe{2}\kilogram\second\tothe{-2}\ampere\tothe{-1}|[1, Table 4]| 
|\tesla|gold|tesla|T|kg s-2 A-1|\kilogram\second\tothe{-2}\ampere\tothe{-1}|[1, Table 4]| 
|\henry|gold|henry|H|m2 kg s-2 A-2|\metre\tothe{2}\kilogram\second\tothe{-2}\ampere\tothe{-2}|[1, Table 4]| 
|\degreecelsius|gold|degree Celsius|°C|K|\kelvin|[1, Table 4]| 
|\lumen|gold|lumen|lm|m2 m-2 cd|\metre\tothe{2}\metre\tothe{-2}\candela|[1, Table 4]| 
|\lux|gold|lux|lx|m-2 cd|\metre\tothe{-2}\candela|[1, Table 4]| 
|\becquerel|gold|becquerel|Bq|s-1|\second\tothe{-1}|[1, Table 4]| 
|\sievert|gold|sievert|Sv|m2 s-2|\metre\tothe{2}\second\tothe{-2}|[1, Table 4]| 
|\gray|gold|gray|Gy|m2 s-2|\metre\tothe{2}\second\tothe{-2}|[1, Table 4]| 
|\katal|gold|katal|kat|s-1 mol|\second\tothe{-1}\mole|[1, Table 4]| 
|\bit<sup>(d</sup>|gold|bit|bit|1|\one|[1, p. 143]| 
|\byte<sup>(e</sup>|gold|byte|B|1|\one|[1, p. 143]| 
|\ppm<sup>(f</sup>|gold|parts per million|ppm|1|\one|[1, Sec. 5.4.7]| 
|\percent<sup>(g</sup>|gold|percent|%|1|\one|[1, Sec. 5.4.7]|"

<sub>(c: The unit gram must not be combined with the prefix kilo. </sub>

<sub>(d: Binary prefixes are the only allowed prefixes for unit bit. </sub>

<sub>(e: Binary prefixes are the only allowed prefixes for unit byte. </sub>

<sub>(f: Unit ppm (parts per million) must not be used with a prefix of an exponent. </sub>

<sub>(g: Unit percent must not be used with a prefix of an exponent. </sub>

## Non-SI units of measurement allowed with the SI 
|D-SI Identifier|D-SI Medal|SI name|SI symbol |SI base unit expression|D-SI base unit expression|SI Reference| 
|-:|-:|-:|-:|-:|-:|-:| 
|\minute|silver|minute|min|s|\second|[1, Table 8]|
|\hour|silver|hour|h|s|\second|[1, Table 8]|
|\day|silver|day|d|s|\second|[1, Table 8]|
|\degree|silver|degree|°|rad|\radian|[1, Table 8]|
|\arcminute|silver|second (arc second)|"|rad|\radian|[1, Table 8]|
|\arcsecond|silver|second (arc second)|'|rad|\radian|[1, Table 8]|
|\hectare|silver|hectare|ha|m2|\metre\tothe{2}|[1, Table 8]| 
|\litre|silver|litre|l|m3|\metre\tothe{3}|[1, Table 8]| 
|\tonne|silver|tonne|t|kg|\kilogram|[1, Table 8]| 
|\electronvolt|silver|electronvolt|eV|m2 kg s-2|\metre\tothe{2}\kilogram\second\tothe{-2}|[1, Table 8]| 
|\dalton|silver|dalton|Da|kg|\kilogram|[1, Table 8]| 
|\astronomicalunit|silver|astronomical unit|au|m|\metre|[1, Table 8]| 
|\neper|silver|neper|Np|1|\one|[1, Table 8]| 
|\bel<sup>(h</sup>|silver|bel|B|1|\one|[1, Table 8]| 
|\decibel<sup>(i</sup>|silver|decibel(b|dB|1|\one|[1, Table 8]|"

<sub>(h: The unit bel must not be combined with the prefix deci. </sub>

<sub>(i: The unit decibel must not be combined with any prefix. </sub>

## SI prefixes decimal
|D-SI Identifier<sup>(j</sup>|D-SI Medal|SI name|SI symbol |Multiplyer|SI Reference|
|-:|-:|-:|-:|-:|-:|
|\deca|gold|deca(a|da|10|[1, Table 7]|
|\hecto|gold|hecto(a|h|100|[1, Table 7]|
|\kilo<sup>(k</sup>|gold|kilo(a,b|k|1000|[1, Table 7]|
|\mega|gold|mega(a|M|1000000|[1, Table 7]|
|\giga|gold|giga(a|G|1000000000|[1, Table 7]|
|\tera|gold|tera(a|T|1000000000000|[1, Table 7]|
|\peta|gold|peta(a|P|1000000000000000|[1, Table 7]|
|\exa|gold|exa(a|E|1000000000000000000|[1, Table 7]|
|\zetta|gold|zetta(a|Z|1000000000000000000000|[1, Table 7]|
|\yotta|gold|yotta(a|Y|1000000000000000000000000|[1, Table 7]|
|\ronna|gold|ronna|R|1000000000000000000000000000|[2, Resolution 3]|
|\quetta|gold|quetta|Q|1000000000000000000000000000000|[2, Resolution 3]|
|\deci<sup>(l</sup>|gold|deci(a ,b|d|0.1|[1, Table 7]|
|\centi|gold|centi(a|c|0.01|[1, Table 7]|
|\milli|gold|milli(a|m|0.001|[1, Table 7]|
|\micro|gold|micro(a|μ|0.000001|[1, Table 7]|
|\nano|gold|nano(a|n|0.000000001|[1, Table 7]|
|\pico|gold|pico(a|p|0.000000000001|[1, Table 7]|
|\femto|gold|femto(a|f|0.000000000000001|[1, Table 7]|
|\atto|gold|atto(a|a|0.000000000000000001|[1, Table 7]|
|\zepto|gold|zepto(a|z|0.000000000000000000001|[1, Table 7]|
|\yocto|gold|yocto(a|y|0.000000000000000000000001|[1, Table 7]|
|\ronto|gold|ronto|r|0.000000000000000000000000001|[2, Resolution 3]|
|\quecto|gold|quecto|q|0.000000000000000000000000000001|[2, Resolution 3]|"

<sub>(j: All prefixes must not be combined with the units kilogram, decibal, one, bit, and byte. </sub>

<sub>(k: The prefix kilo must not be combined with the unit gram. </sub>

<sub>(l: The prefix deci must not be combined with the unit bel. </sub>

## SI prefixes binary
|D-SI Identifier<sup>(m</sup>|D-SI Medal|SI name|SI symbol |Multiplyer|SI Reference|
|-:|-:|-:|-:|-:|-:|
|\kibi|gold|kibi|Ki |1024|[1, p. 143]|
|\mebi|gold|mebi|Mi|1048576|[1, p. 143]|
|\gibi|gold|gibi|Gi|1073741824|[1, p. 143]|
|\tebi|gold|tebi|Ti|1099511627776|[1, p. 143]|
|\pebi|gold|pebi|Pi|1125899906842624|[1, p. 143]|
|\exbi|gold|exbi|Ei|1152921504606846976|[1, p. 143]|
|\zebi|gold|zebi |Zi|1180591620717411303424|[1, p. 143]|
|\yobi|gold|yobi |Yi|1208925819614629174706176|[1, p. 143]|"

<sub>(m: The binary prefixes are only allowed to be used with units bit and byte. </sub>

## Additional units from 8th edition of the SI-brochure 
|D-SI Identifier|D-SI Medal|SI name|SI symbol |SI base unit expression|D-SI base unit expression|SI Reference| 
|-:|-:|-:|-:|-:|-:|-:| 
|\clight|bronze|n.u. of speed|*c<sub>0</sub>*|m s-1|\metre\second\tothe{-1}|[3, Table 7]| 
|\planckbar|bronze|n.u. of action and a.u. of action|*ħ*|J s|\joule\second|[3, Table 7]|
|\electronmass|bronze|n.u. of mass and a.u. of mass|*m<sub>e</sub>*|kg|\kilogram|[3, Table 7]| \atomicmassunit
|\naturalunittime|bronze|n.u. of time|*ħ (m<sub>e</sub>-1 c<sub>0</sub>-2)*|s|\second|[3, Table 7]| 
|\elementarycharge|bronze|a.u. of charge|*e*|C|\coulomb|[3, Table 7]| atomicunittime
|\atomicunittime|bronze |a.u. of time|ħ E<sub>h</sub>-1|s|\second|[3, Table 7]|
|\bohr|bronze|a.u. of length|a<sub>0</sub>|m|\metre|[3, Table 7]|
|\hartree|bronze|a.u. of energy|E<sub>h</sub>|J|\joule|[3, Table 7]|
|\bar|bronze|bar|bar|Pa|\pascal|[3, Table 8]|
|\mmHg|bronze|millimetre of mercury|mmHg|Pa|\pascal|[3, Table 8]|
|\angstrom|bronze|ångström|Å|m|\metre|[3, Table 8]|
|\nauticalmile|bronze|nautucalmile|M|m|\metre|[3, Table 8]|
|\barn|bronze|barn|b|m2|\metre\tothe{2}|[3, Table 8]|
|\knot|bronze|knot|kn|m s-1|\metre\second\tothe{-1}|[3, Table 8]|
|\erg|bronze|erg|erg|J|\joule|[3, Table 9]|
|\dyne|bronze|dyne|dyn|N|\newton|[3, Table 9]| 
|\poise|bronze|poise|P|Pa s|\pascal\second|[3, Table 9]| 
|\stokes|bronze|stokes||||[3, Table 9]|
|\stilb|bronze|stilb|sb|m-2|\metre\tothe{-2}|[3, Table 9]| 
|\phot|bronze|phot|ph|lx|\lux|[3, Table 9]| 
|\gal|bronze|gal|Gal|m s-2|\metre\second\tothe{-2}|[3, Table 9]| 
|\maxwell|bronze|maxwell|Mx|Wb|\weber|[3, Table 9]| 
|\gauss|bronze|gauss|G|T|\tesla|[3, Table 9]|
|\aersted|bronze|œrsted|Oe|A m-1|\ampere\metre\tothe{-1}|[3, Table 9]|


\elementarycharge


## Operators for combining units
|D-SI Identifier|Description|Examples|D-SI Medal |
|-:|-:|-:|-:|
| |Multiplication: simply append one unit to another |\metre\metre|PLATINUM|
|\tothe{n} | Exponent: following a unit where n is an integer or (+-)0.5 |\metre\tothe{2}, \second\tothe{-0.5}|PLATINUM|
|\per |Division: All units on the left side of the operator devided by all units on its right side |\metre\per\metre|SILVER|

### References



[1] BIPM: 9th edition SI brochure (englisch): https://www.bipm.org/documents/20126/41483022/SI-Brochure-9-EN.pdf

[2] BIPM: List of Resolutions for the 27th meeting of the General Conference on Weights and Measures 2022: https://www.bipm.org/documents/20126/77765681/Resolutions-2022.pdf/281f3160-fc56-3e63-dbf7-77b76500990f#page=22

[3] BIPM: 8th edition SI brochure (englisch): https://www.bipm.org/documents/20126/41483022/si_brochure_8.pdf

[**Home**](wiki/d-si-online-guide.md) 

<a rel="license" href="http://creativecommons.org/licenses/by/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by/4.0/88x31.png" /></a><br />This documentation is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by/4.0/">Creative Commons Attribution 4.0 International License</a>.


